Root Mean Squared Error (RMSE)
==============================

.. automodule:: viqa.fr_metrics.rmse
    :exclude-members: RMSE

   
.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.rmse

.. autosummary::
    :toctree: generated/
    :template: class.rst

    RMSE